@@ -6,6 +6,7 @@ use Drupal\comment\CommentInterface;
 use Drupal\comment\Tests\CommentTestTrait;
 use Drupal\comment\Entity\Comment;
 use Drupal\Tests\BrowserTestBase;
+use Drupal\user\Entity\User;
 
 /**
  * Tests access controlled node views have the right amount of comment pages.
@@ -21,20 +22,23 @@ class NodeAccessPagerTest extends BrowserTestBase {
    *
    * @var \Drupal\user\Entity\User
    */
-  protected $webUser;
+  protected User $webUser;
 
   /**
    * Modules to enable.
    *
    * @var array
    */
-  protected static $modules = ['node_access_test', 'comment', 'forum'];
+  protected static $modules = ['node', 'node_access_test', 'comment'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
+  /**
+   * {@inheritdoc}
+   */
   protected function setUp(): void {
     parent::setUp();
 
@@ -81,36 +85,4 @@ class NodeAccessPagerTest extends BrowserTestBase {
     $this->assertSession()->responseNotContains('page=2');
   }
 
-  /**
-   * Tests the forum node pager for nodes with multiple grants per realm.
-   */
-  public function testForumPager() {
-    // Look up the forums vocabulary ID.
-    $vid = $this->config('forum.settings')->get('vocabulary');
-    $this->assertNotEmpty($vid, 'Forum navigation vocabulary ID is set.');
-
-    // Look up the general discussion term.
-    $tree = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadTree($vid, 0, 1);
-    $tid = reset($tree)->tid;
-    $this->assertNotEmpty($tid, 'General discussion term is found in the forum vocabulary.');
-
-    // Create 30 nodes.
-    for ($i = 0; $i < 30; $i++) {
-      $this->drupalCreateNode([
-        'nid' => NULL,
-        'type' => 'forum',
-        'taxonomy_forums' => [
-          ['target_id' => $tid],
-        ],
-      ]);
-    }
-
-    // View the general discussion forum page. With the default 25 nodes per
-    // page there should be two pages for 30 nodes, no more.
-    $this->drupalLogin($this->webUser);
-    $this->drupalGet('forum/' . $tid);
-    $this->assertSession()->responseContains('page=1');
-    $this->assertSession()->responseNotContains('page=2');
-  }
-
 }
