@@ -41,30 +41,28 @@ class Sql extends QueryPluginBase {
   public $tables = [];
 
   /**
-   * Holds an array of relationships, which are aliases of the primary
-   * table that represent different ways to join the same table in.
+   * Holds an array of relationships.
+   *
+   * These are aliases of the primary table that represent different ways to
+   * join the same table in.
    */
   public $relationships = [];
 
   /**
-   * An array of sections of the WHERE query. Each section is in itself
-   * an array of pieces and a flag as to whether or not it should be AND
-   * or OR.
+   * An array of sections of the WHERE query.
+   *
+   * Each section is in itself an array of pieces and a flag as to whether or
+   * not it should be AND or OR.
    */
+
   public $where = [];
   /**
-   * An array of sections of the HAVING query. Each section is in itself
-   * an array of pieces and a flag as to whether or not it should be AND
-   * or OR.
+   * An array of sections of the HAVING query.
+   *
+   * Each section is in itself an array of pieces and a flag as to whether or
+   * not it should be AND or OR.
    */
   public $having = [];
-  /**
-   * The default operator to use when connecting the WHERE groups. May be
-   * AND or OR.
-   *
-   * @var string
-   */
-  protected $groupOperator = 'AND';
 
   /**
    * A simple array of order by clauses.
@@ -137,6 +135,11 @@ class Sql extends QueryPluginBase {
    */
   protected $messenger;
 
+  /**
+   * The count field definition.
+   */
+  public array $count_field;
+
   /**
    * Constructs a Sql object.
    *
@@ -154,6 +157,9 @@ class Sql extends QueryPluginBase {
    *   The messenger.
    */
   public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, DateSqlInterface $date_sql, MessengerInterface $messenger) {
+    // By default, use AND operator to connect WHERE groups.
+    $this->groupOperator = 'AND';
+
     parent::__construct($configuration, $plugin_id, $plugin_definition);
 
     $this->entityTypeManager = $entity_type_manager;
@@ -237,7 +243,7 @@ class Sql extends QueryPluginBase {
    * Set the view to be distinct (per base field).
    *
    * @param bool $value
-   *   Should the view be distincted.
+   *   Should the view be distinct.
    */
   protected function setDistinct($value = TRUE) {
     if (!(isset($this->noDistinct) && $value)) {
@@ -338,6 +344,8 @@ class Sql extends QueryPluginBase {
   }
 
   /**
+   * Adds a relationship to the query.
+   *
    * A relationship is an alternative endpoint to a series of table
    * joins. Relationships must be aliases of the primary table and
    * they must join either to the primary table or to a pre-existing
@@ -566,12 +574,14 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Ensure a table exists in the queue; if it already exists it won't
-   * do anything, but if it doesn't it will add the table queue. It will ensure
-   * a path leads back to the relationship table.
+   * Ensures a table exists in the queue.
+   *
+   * If it already exists it won't do anything, but if it doesn't it will add
+   * the table queue. It will ensure a path leads back to the relationship
+   * table.
    *
    * @param $table
-   *   The unaliased name of the table to ensure.
+   *   The un-aliased name of the table to ensure.
    * @param $relationship
    *   The relationship to ensure the table links to. Each relationship will
    *   get a unique instance of the table being added. If not specified,
@@ -579,7 +589,7 @@ class Sql extends QueryPluginBase {
    * @param \Drupal\views\Plugin\views\join\JoinPluginBase $join
    *   A Join object (or derived object) to join the alias in.
    *
-   * @return
+   * @return string|null
    *   The alias used to refer to this specific table, or NULL if the table
    *   cannot be ensured.
    */
@@ -656,11 +666,11 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Make sure that the specified table can be properly linked to the primary
-   * table in the JOINs. This function uses recursion. If the tables
-   * needed to complete the path back to the primary table are not in the
-   * query they will be added, but additional copies will NOT be added
-   * if the table is already there.
+   * Ensures the given table can be linked to the primary table in the JOINs.
+   *
+   * This function uses recursion. If the tables needed to complete the path
+   * back to the primary table are not in the query they will be added, but
+   * additional copies will NOT be added if the table is already there.
    */
   protected function ensurePath($table, $relationship = NULL, $join = NULL, $traced = [], $add = []) {
     if (!isset($relationship)) {
@@ -711,8 +721,10 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Fix a join to adhere to the proper relationship; the left table can vary
-   * based upon what relationship items are joined in on.
+   * Fixes a join to adhere to the proper relationship.
+   *
+   * The left table can vary based upon what relationship items are joined in
+   * on.
    */
   protected function adjustJoin($join, $relationship) {
     if (!empty($join->adjusted)) {
@@ -797,8 +809,9 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Add a field to the query table, possibly with an alias. This will
-   * automatically call ensureTable to make sure the required table
+   * Adds a field to the query table, possibly with an alias.
+   *
+   * This will automatically call ensureTable to make sure the required table
    * exists, *unless* $table is unset.
    *
    * @param $table
@@ -873,17 +886,20 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Remove all fields that may have been added; primarily used for summary mode
-   * where we're changing the query because we didn't get data we needed.
+   * Removes all fields that may have been added.
+   *
+   * Primarily used for summary mode where we're changing the query because
+   * we didn't get data we needed.
    */
   public function clearFields() {
     $this->fields = [];
   }
 
   /**
-   * Add a simple WHERE clause to the query. The caller is responsible for
-   * ensuring that all fields are fully qualified (TABLE.FIELD) and that
-   * the table already exists in the query.
+   * Adds a simple WHERE clause to the query.
+   *
+   * The caller is responsible for ensuring that all fields are fully qualified
+   * (TABLE.FIELD) and that the table already exists in the query.
    *
    * The $field, $value and $operator arguments can also be passed in with a
    * single DatabaseCondition object, like this:
@@ -934,7 +950,7 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Add a complex WHERE clause to the query.
+   * Adds a complex WHERE clause to the query.
    *
    * The caller is responsible for ensuring that all fields are fully qualified
    * (TABLE.FIELD) and that the table already exists in the query.
@@ -973,6 +989,7 @@ class Sql extends QueryPluginBase {
 
   /**
    * Add a complex HAVING clause to the query.
+   *
    * The caller is responsible for ensuring that all fields are fully qualified
    * (TABLE.FIELD) and that the table and an appropriate GROUP BY already exist in the query.
    * Internally the dbtng method "having" is used.
@@ -1055,9 +1072,10 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Add a simple GROUP BY clause to the query. The caller is responsible
-   * for ensuring that the fields are fully qualified and the table is properly
-   * added.
+   * Add a simple GROUP BY clause to the query.
+   *
+   * The caller is responsible for ensuring that the fields are fully qualified
+   * and the table is properly added.
    */
   public function addGroupBy($clause) {
     // Only add it if it's not already in there.
@@ -1074,7 +1092,7 @@ class Sql extends QueryPluginBase {
    * @see \Drupal\views\Plugin\views\query\Sql::addField
    */
   protected function getFieldAlias($table_alias, $field) {
-    return isset($this->fieldAliases[$table_alias][$field]) ? $this->fieldAliases[$table_alias][$field] : FALSE;
+    return $this->fieldAliases[$table_alias][$field] ?? FALSE;
   }
 
   /**
@@ -1275,11 +1293,10 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Generate a query and a countquery from all of the information supplied
-   * to the object.
+   * Generates a query and count query from all of the information supplied.
    *
    * @param $get_count
-   *   Provide a countquery if this is true, otherwise provide a normal query.
+   *   Provide a countQuery if this is true, otherwise provide a normal query.
    */
   public function query($get_count = FALSE) {
     // Check query distinct value.
@@ -1350,14 +1367,14 @@ class Sql extends QueryPluginBase {
     $entity_information = $this->getEntityTableInfo();
     if ($entity_information) {
       $params = [];
-      if ($groupby) {
+      if ($this->hasAggregate) {
         // Handle grouping, by retrieving the minimum entity_id.
         $params = [
           'function' => 'min',
         ];
       }
 
-      foreach ($entity_information as $entity_type_id => $info) {
+      foreach ($entity_information as $info) {
         $entity_type = \Drupal::entityTypeManager()->getDefinition($info['entity_type']);
         $base_field = !$info['revision'] ? $entity_type->getKey('id') : $entity_type->getKey('revision');
         $this->addField($info['alias'], $base_field, '', $params);
@@ -1422,14 +1439,7 @@ class Sql extends QueryPluginBase {
    * Get the arguments attached to the WHERE and HAVING clauses of this query.
    */
   public function getWhereArgs() {
-    $args = [];
-    foreach ($this->where as $where) {
-      $args = array_merge($args, $where['args']);
-    }
-    foreach ($this->having as $having) {
-      $args = array_merge($args, $having['args']);
-    }
-    return $args;
+    return array_merge(...array_column($this->where, 'args'), ...array_column($this->having, 'args'));
   }
 
   /**
@@ -1461,8 +1471,7 @@ class Sql extends QueryPluginBase {
   }
 
   /**
-   * Executes the query and fills the associated view object with according
-   * values.
+   * Executes the query and fills associated view object with according values.
    *
    * Values to set: $view->result, $view->total_rows, $view->execute_time,
    * $view->current_page.
@@ -1624,6 +1633,7 @@ class Sql extends QueryPluginBase {
 
     // Now load all revisions.
     foreach ($revision_ids_by_type as $entity_type => $revision_ids) {
+      /** @var \Drupal\Core\Entity\RevisionableStorageInterface $entity_storage */
       $entity_storage = $this->entityTypeManager->getStorage($entity_type);
       $entities = [];
 
