@@ -1,9 +1,6 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\Tests\Core\UrlTest.
- */
+declare(strict_types=1);
 
 namespace Drupal\Tests\Core;
 
@@ -14,8 +11,8 @@ use Drupal\Core\GeneratedUrl;
 use Drupal\Core\Routing\RouteMatch;
 use Drupal\Core\Url;
 use Drupal\Tests\UnitTestCase;
-use Symfony\Cmf\Component\Routing\RouteObjectInterface;
-use Symfony\Component\HttpFoundation\ParameterBag;
+use Drupal\Core\Routing\RouteObjectInterface;
+use Symfony\Component\HttpFoundation\InputBag;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\Routing\Exception\InvalidParameterException;
 use Symfony\Component\Routing\Exception\ResourceNotFoundException;
@@ -33,7 +30,7 @@ class UrlTest extends UnitTestCase {
   protected $container;
 
   /**
-   * The URL generator
+   * The URL generator.
    *
    * @var \Drupal\Core\Routing\UrlGeneratorInterface|\PHPUnit\Framework\MockObject\MockObject
    */
@@ -99,12 +96,12 @@ class UrlTest extends UnitTestCase {
     $this->urlGenerator = $this->createMock('Drupal\Core\Routing\UrlGeneratorInterface');
     $this->urlGenerator->expects($this->any())
       ->method('generateFromRoute')
-      ->will($this->returnValueMap($generate_from_route_map));
+      ->willReturnMap($generate_from_route_map);
 
     $this->pathAliasManager = $this->createMock('Drupal\path_alias\AliasManagerInterface');
     $this->pathAliasManager->expects($this->any())
       ->method('getPathByAlias')
-      ->will($this->returnValueMap($alias_map));
+      ->willReturnMap($alias_map);
 
     $this->router = $this->createMock('Drupal\Tests\Core\Routing\TestRouterInterface');
     $this->pathValidator = $this->createMock('Drupal\Core\Path\PathValidatorInterface');
@@ -118,29 +115,25 @@ class UrlTest extends UnitTestCase {
   }
 
   /**
-   * Tests creating a Url from a request.
+   * Tests creating a URL from a request.
    */
   public function testUrlFromRequest() {
-    $this->router->expects($this->at(0))
+    $this->router->expects($this->exactly(3))
       ->method('matchRequest')
-      ->with($this->getRequestConstraint('/node'))
-      ->willReturn([
-          RouteObjectInterface::ROUTE_NAME => 'view.frontpage.page_1',
-          '_raw_variables' => new ParameterBag(),
-        ]);
-    $this->router->expects($this->at(1))
-      ->method('matchRequest')
-      ->with($this->getRequestConstraint('/node/1'))
-      ->willReturn([
+      ->withConsecutive(
+        [$this->getRequestConstraint('/node')],
+        [$this->getRequestConstraint('/node/1')],
+        [$this->getRequestConstraint('/node/2/edit')],
+      )
+      ->willReturnOnConsecutiveCalls([
+        RouteObjectInterface::ROUTE_NAME => 'view.frontpage.page_1',
+        '_raw_variables' => new InputBag(),
+      ], [
         RouteObjectInterface::ROUTE_NAME => 'node_view',
-        '_raw_variables' => new ParameterBag(['node' => '1']),
-      ]);
-    $this->router->expects($this->at(2))
-      ->method('matchRequest')
-      ->with($this->getRequestConstraint('/node/2/edit'))
-      ->willReturn([
+        '_raw_variables' => new InputBag(['node' => '1']),
+      ], [
         RouteObjectInterface::ROUTE_NAME => 'node_edit',
-        '_raw_variables' => new ParameterBag(['node' => '2']),
+        '_raw_variables' => new InputBag(['node' => '2']),
       ]);
 
     $urls = [];
@@ -259,7 +252,7 @@ class UrlTest extends UnitTestCase {
    */
   public function testCreateFromRequest() {
     $attributes = [
-      '_raw_variables' => new ParameterBag([
+      '_raw_variables' => new InputBag([
         'color' => 'chartreuse',
       ]),
       RouteObjectInterface::ROUTE_NAME => 'the_route_name',
@@ -269,7 +262,7 @@ class UrlTest extends UnitTestCase {
     $this->router->expects($this->once())
       ->method('matchRequest')
       ->with($request)
-      ->will($this->returnValue($attributes));
+      ->willReturn($attributes);
 
     $url = Url::createFromRequest($request);
     $expected = new Url('the_route_name', ['color' => 'chartreuse']);
@@ -361,14 +354,14 @@ class UrlTest extends UnitTestCase {
     $map[] = ['node_view', ['node' => '1'], '/node/1'];
     $map[] = ['node_edit', ['node' => '2'], '/node/2/edit'];
 
-    foreach ($urls as $index => $url) {
-      // Clone the url so that there is no leak of internal state into the
+    foreach ($urls as $url) {
+      // Clone the URL so that there is no leak of internal state into the
       // other ones.
       $url = clone $url;
       $url_generator = $this->createMock('Drupal\Core\Routing\UrlGeneratorInterface');
       $url_generator->expects($this->once())
         ->method('getPathFromRoute')
-        ->will($this->returnValueMap($map, $index));
+        ->willReturnMap($map);
       $url->setUrlGenerator($url_generator);
 
       $url->getInternalPath();
@@ -495,6 +488,7 @@ class UrlTest extends UnitTestCase {
    * Tests the access() method for routed URLs.
    *
    * @param bool $access
+   *   The access value.
    *
    * @covers ::access
    * @covers ::accessManager
@@ -526,9 +520,11 @@ class UrlTest extends UnitTestCase {
    * Tests the renderAccess() method.
    *
    * @param bool $access
+   *   The access value.
    *
    * @covers ::renderAccess
    * @dataProvider accessProvider
+   * @group legacy
    */
   public function testRenderAccess($access) {
     $element = [
@@ -536,9 +532,22 @@ class UrlTest extends UnitTestCase {
     ];
     $this->container->set('current_user', $this->createMock('Drupal\Core\Session\AccountInterface'));
     $this->container->set('access_manager', $this->getMockAccessManager($access));
+    $this->expectDeprecation('Drupal\Core\Url::renderAccess() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3342977');
     $this->assertEquals($access, TestUrl::renderAccess($element));
   }
 
+  /**
+   * Tests deprecation of toRenderArray() method.
+   *
+   * @covers ::toRenderArray
+   * @group legacy
+   */
+  public function testToRenderArray() {
+    $this->expectDeprecation('Drupal\Core\Url::toRenderArray() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3342977');
+    $url = Url::fromRoute('entity.node.canonical', ['node' => 3]);
+    $this->assertIsArray($url->toRenderArray());
+  }
+
   /**
    * Tests the fromRouteMatch() method.
    */
@@ -551,7 +560,7 @@ class UrlTest extends UnitTestCase {
   }
 
   /**
-   * Data provider for testing entity URIs
+   * Data provider for testing entity URIs.
    */
   public function providerTestEntityUris() {
     return [
@@ -653,7 +662,7 @@ class UrlTest extends UnitTestCase {
   }
 
   /**
-   * Data provider for testing string entity URIs
+   * Data provider for testing string entity URIs.
    */
   public function providerTestToUriStringForEntity() {
     return [
@@ -836,7 +845,9 @@ class UrlTest extends UnitTestCase {
    * Creates a mock access manager for the access tests.
    *
    * @param bool $access
+   *   The access value.
    * @param \Drupal\Core\Session\AccountInterface|null $account
+   *   The account to test.
    *
    * @return \Drupal\Core\Access\AccessManagerInterface|\PHPUnit\Framework\MockObject\MockObject
    */
@@ -867,6 +878,7 @@ class TestUrl extends Url {
    * Sets the access manager.
    *
    * @param \Drupal\Core\Access\AccessManagerInterface $access_manager
+   *   The access manager.
    */
   public function setAccessManager(AccessManagerInterface $access_manager) {
     $this->accessManager = $access_manager;
